@@ -26,6 +26,9 @@ class CaptchaChromeBase:
     BLOCKED = "Access denied"
     SUSPICIOUS = "Pardon our interruption"
     CAPTCHA_ATTEMPTS = 4
+    WAIT_MSG = "Please wait while we process your request"
+    MAX_WAIT = 60
+    LONG_SLEEP = 60
     instances = []
 
     def __init__(self, *args, **kwargs):
@@ -36,6 +39,9 @@ class CaptchaChromeBase:
         super().__init__(*args, **kwargs)
 
     def solve_captcha(self) -> bool:
+        if self.INCAPSULA not in self.page_source:
+            return True
+
         self.switch_to.default_content()
         iframe = self.find_element(value="main-iframe", bypass=False)
         self.switch_to.frame(iframe)
@@ -107,7 +113,8 @@ class CaptchaChromeBase:
                     solved = True
 
                 if self.INCAPSULA in self.page_source:
-                    randsleep(150)
+                    self._logger.debug("Long sleep as incapsula still in page source.")
+                    randsleep(self.LONG_SLEEP)
                 else:
                     solved = True
         else:
@@ -119,9 +126,21 @@ class CaptchaChromeBase:
             self._logger.error("Unable to beat Captcha")
             raise BrowserError("Unable to beat Captcha")
 
-    def find_element(self, by=None, value=None, bypass=True):
+    def wait(self):
+        waited = 0
+        self._logger.debug("Waiting as page is not ready yet.")
+        while self.WAIT_MSG in self.page_source and waited < self.MAX_WAIT:
+            sleep(1)
+            waited += 1
+        if self.WAIT_MSG in self.page_source:
+            raise BrowserError(f"Page failed to load within {self.MAX_WAIT} s")
+
+    def find_element(self, by=None, value=None, bypass=True, wait=True):
         if bypass:
             self.bypass()
+        if wait:
+            self.wait()
+
         args = dict(by=by, value=value)
         return super().find_element(**{k: v for k, v in args.items() if v})
 
@@ -224,11 +243,15 @@ class Browser:
         return f"--remote-debugging-port={self.port}"
 
     def kill(self, proc, name):
-        self._logger.info(f"Killing {name}")
         if not proc:
             return
+        self._logger.info(f"Killing {name}")
+
+        if isinstance(proc, int):
+            sysproc = Process(proc)
+        else:
+            sysproc = Process(proc.pid)
 
-        sysproc = Process(proc.pid)
         for child in sysproc.children(recursive=True):
             try:
                 child.terminate()
@@ -241,6 +264,9 @@ class Browser:
             except Exception:
                 pass
 
+        if isinstance(proc, int):
+            return
+
         proc.terminate()
         proc.wait(2)
         if proc.poll() is None:
@@ -336,12 +362,12 @@ class Browser:
                 self._dump(exc_type, exc_val, exc_tb)
             except Exception as e:
                 tb.print_exc()
+        self.kill(self._proc, "Chrome")
         try:
             self._driver.quit()
         except Exception:
             pass
 
-        self.kill(self._proc, "Chrome")
         try:
             self._profile_dir.cleanup()
         except Exception as e:
